@@ -22,7 +22,6 @@ import abc
 import shutil
 import logging
 import inspect
-import warnings
 import traceback
 
 # Local library
@@ -263,37 +262,83 @@ class Conform(Plugin):
 
 
 class AbstractEntity(list):
-    __metaclass__ = abc.ABCMeta
 
     def __repr__(self):
-        return u"%s(%r)" % (type(self).__name__, self.__str__())
+        return u"%s.%s()" % (__name__, type(self).__name__)
 
     def __str__(self):
-        return str([i for i in self])
+        return "Context"
 
     def __init__(self):
         self._data = dict()
 
     def add(self, other):
+        """Add member to self
+
+        This is to mimic the interface of set()
+
+        """
+
         if not other in self:
-            self.append(other)
+            return self.append(other)
 
     def remove(self, other):
-        self.remove(other)
+        """Remove member from self
+
+        This is to mimic the interface of set()
+
+        """
+
+        index = self.index(other)
+        return self.pop(index)
 
     def data(self, key=None, default=None):
+        """Return data from `key`
+
+        Arguments:
+            key (str): Name of data to return
+            default (object): Optional, value returned if `name`
+                does not exist
+
+        """
+
         if key is None:
             return self._data
 
         return self._data.get(key, default)
 
     def set_data(self, key, value):
+        """Modify/insert data into entity
+
+        Arguments:
+            key (str): Name of data to add
+            value (object): Value of data to add
+
+        """
+
         self._data[key] = value
 
     def remove_data(self, key):
+        """Remove data from entity
+
+        Arguments;
+            key (str): Name of data to remove
+
+        """
+
         self._data.pop(key)
 
     def has_data(self, key):
+        """Check if entity has key
+
+        Arguments:
+            key (str): Key to check
+
+        Return:
+            True if it exists, False otherwise
+
+        """
+
         return key in self._data
 
 
@@ -301,12 +346,16 @@ class Context(AbstractEntity):
     """Maintain a collection of Instances"""
 
     def create_instance(self, name):
-        """Convenience method for the following.
+        """Convenience method of the following.
 
         >>> ctx = Context()
         >>> inst = Instance('name', parent=ctx)
         >>> ctx.add(inst)
 
+        Example:
+            >>> ctx = Context()
+            >>> inst = ctx.create_instance(name='Name')
+
         """
 
         instance = Instance(name, parent=self)
@@ -332,29 +381,11 @@ class Instance(AbstractEntity):
     def __ne__(self, other):
         return str(other) != str(self)
 
-    def __hash__(self):
-        """Ensure instance is unique within list
-
-        Example:
-            >>> ctx = Context()
-            >>> inst1 = Instance(name='inst1')
-            >>> inst2 = Instance(name='inst2')
-            >>> ctx.add(inst1)
-            >>> inst2 in ctx
-            False
-            >>> ctx.add(inst2)
-            >>> inst2 in ctx
-            True
-            >>> inst_ = Instance(name='inst2')
-            >>> inst_ in ctx
-            True
-
-        """
-
-        return hash(str(self))
+    def __repr__(self):
+        return u"%s.%s('%s')" % (__name__, type(self).__name__, self)
 
     def __str__(self):
-        return str(self.name)
+        return self.name
 
     def __init__(self, name, parent=None):
         super(Instance, self).__init__()
@@ -396,13 +427,6 @@ class Instance(AbstractEntity):
 
         return value
 
-    @property
-    def config(self):
-        warnings.warn("config deprecated, use .data() instead.",
-                      DeprecationWarning,
-                      stacklevel=2)
-        return self._data
-
 
 def current_host():
     """Return currently active host
@@ -630,6 +654,12 @@ def _discover_type(type, paths, regex=None):
     # differently. Do a check here.
     discovered_paths = list()
 
+    try:
+        print "Trying "
+        pattern = patterns[type]
+    except KeyError:
+        raise  # Handled by :func:discover()
+
     # Look through each registered path for potential plugins
     for path in paths:
         log.debug("Looking for plugins in: \n%s", path)
@@ -653,11 +683,6 @@ def _discover_type(type, paths, regex=None):
 
             mod_name, suffix = os.path.splitext(fname)
 
-            try:
-                pattern = patterns[type]
-            except KeyError:
-                raise  # Handled below
-
             # Modules that don't match the regex aren't plugins.
             if not re.match(pattern, fname):
                 continue
